@@ -3,6 +3,7 @@ package cli
 import (
 	"fmt"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
 	"github.com/jandedobbeleer/oh-my-posh/src/engine"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
@@ -71,6 +72,8 @@ func runInit(shellName string) {
 	shell.ErrorLine = cfg.ErrorLine != nil || cfg.ValidLine != nil
 	shell.Tooltips = len(cfg.Tooltips) > 0
 	shell.ShellIntegration = cfg.ShellIntegration
+	shell.PromptMark = shellName == shell.FISH && cfg.ITermFeatures != nil && cfg.ITermFeatures.Contains(ansi.PromptMark)
+	shell.AutoUpgrade = cfg.AutoUpgrade && upgrade.Supported
 
 	for i, block := range cfg.Blocks {
 		// only fetch cursor position when relevant
@@ -83,7 +86,7 @@ func runInit(shellName string) {
 	}
 
 	// allow overriding the upgrade notice from the config
-	if cfg.DisableNotice {
+	if cfg.DisableNotice || cfg.AutoUpgrade {
 		env.Cache().Set(upgrade.CACHEKEY, "disabled", -1)
 	}
 
