@@ -53,6 +53,7 @@ var (
 	RPrompt           bool
 	CursorPositioning bool
 	PromptMark        bool
+	AutoUpgrade       bool
 )
 
 func getExecutablePath(env platform.Environment) (string, error) {
@@ -283,6 +284,7 @@ func PrintInit(env platform.Environment) string {
 		"::CURSOR::", strconv.FormatBool(CursorPositioning),
 		"::UPGRADE::", strconv.FormatBool(hasNotice),
 		"::UPGRADENOTICE::", notice,
+		"::AUTOUPGRADE::", strconv.FormatBool(AutoUpgrade),
 		"::PROMPT_MARK::", promptMark(),
 	).Replace(script)
 }
